==> haskell-js-flot-0.8.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-flot
version: 0.8.3
id: js-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn
key: js-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn
license: MIT
copyright: Neil Mitchell 2014
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-flot#readme
synopsis: Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Javascript.Flot
hidden-modules: Paths_js_flot
abi: 2106e2792b3341c959c8f349c22f5bf9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/js-flot-0.8.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-flot
hs-libraries: HSjs-flot-0.8.3-BVv7WjS6mgVJLBMR8vaufn
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html: /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-flot-0.8.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-flot
version: 0.8.3
id: js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
key: js-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
license: MIT
copyright: Neil Mitchell 2014
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-flot#readme
synopsis: Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: 22192e8eaba4308c5317363c4da3caab
exposed: True
exposed-modules:
    Language.Javascript.Flot
hidden-modules: Paths_js_flot
import-dirs: /usr/lib/ghc-8.4.3/site-local/js-flot-0.8.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-flot
hs-libraries: HSjs-flot-0.8.3-Bsjxmw7L5o0BiJSkgBCarQ
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html: /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
